/*
 * file: PvEngineAttr.c
 * This file is part of the libpv library.
 *
 * Copyright 2005 Pengutronix
 *
 * Please send bug reports to bugs@pengutronix.de
 *
 * See COPYING for the status of this software.
 */

#include <stdio.h>
#include <string.h>

#include <Python.h>
#include <structmember.h>

#include "PvEngineAttr.h"

PyObject *PvEngineAttr_new(PyTypeObject *type, PyObject *args, PyObject *keywds)
{
	char *desc_filename;
	char *store_filename;
	PvEngineAttrObject *self;
	int ret;
	static char *kwlist[] = { "desc", "store", NULL };

	//printf("DEBUG: %s\n", __FUNCTION__);

	if (!PyArg_ParseTupleAndKeywords(args, keywds, "ss", kwlist,
			&desc_filename, &store_filename))
		return NULL;

	self = (PvEngineAttrObject*)type->tp_alloc(type, 0);
	if (!self)
		return NULL;

	ret = pv_engine_attr_init(&(self->attr));
	if (ret != 0) {
		PyErr_SetString(PyExc_AttributeError, "pv_engine_attr_init failed.");
		Py_DECREF(self);
		return NULL;
	}

	strncpy(self->attr.desc_filename, desc_filename, NAME_MAX);
	strncpy(self->attr.store_filename, store_filename, NAME_MAX);

	return (PyObject *)self;
}

PyMethodDef PvEngineAttr_methods[] = {
	{NULL},
};

PyMemberDef PvEngineAttr_members[] = {
	{"desc", T_STRING, offsetof(PvEngineAttrObject, attr.desc_filename), RO},
	{"store", T_STRING, offsetof(PvEngineAttrObject, attr.store_filename), RO},
	{NULL},
};

void PvEngineAttr_dealloc(PvEngineAttrObject *self)
{
	//printf("DEBUG: %s\n", __FUNCTION__);

	PyObject_Del(self);
}

PyTypeObject PvEngineAttr_Type = {
	/* The ob_type field must be initialized in the module init function
	 * to be portable to Windows without using C++. */
	PyObject_HEAD_INIT(NULL)	/*ob_type*/
	0,				/*ob_size*/
	"libpv.PvEngineAttr",		/*tp_name*/
	sizeof(PvEngineAttrObject),	/*tp_basicsize*/
	0,				/*tp_itemsize*/
	/* methods */
	(destructor)PvEngineAttr_dealloc,/*tp_dealloc*/
	0,				/*tp_print*/
	0,				/*tp_getattr*/
	0,				/*tp_setattr*/
	0,				/*tp_compare*/
	0,				/*tp_repr*/
	0,				/*tp_as_number*/
	0,				/*tp_as_sequence*/
	0,				/*tp_as_mapping*/
	0,				/*tp_hash*/
	0,				/*tp_call*/
	0,				/*tp_str*/
	0,				/*tp_getattro*/
	0,				/*tp_setattro*/
	0,				/*tp_as_buffer*/
	Py_TPFLAGS_DEFAULT,		/*tp_flags*/
	0,				/*tp_doc*/
	0,				/*tp_traverse*/
	0,				/*tp_clear*/
	0,				/*tp_richcompare*/
	0,				/*tp_weaklistoffset*/
	0,				/*tp_iter*/
	0,				/*tp_iternext*/
	PvEngineAttr_methods,		/*tp_methods*/
	PvEngineAttr_members,		/*tp_members*/
	0,				/*tp_getset*/
	0,				/*tp_base*/
	0,				/*tp_dict*/
	0,				/*tp_descr_get*/
	0,				/*tp_descr_set*/
	0,				/*tp_dictoffset*/
	0,				/*tp_init*/
	0,				/*tp_alloc*/
	(newfunc)PvEngineAttr_new,	/*tp_new*/
	0,				/*tp_free*/
	0,				/*tp_is_gc*/
};

